@@ -6,6 +6,8 @@ import pyro.distributions as dist
 import pyro.poutine as poutine
 import torch
 from torch.distributions import constraints
+import mobster.utils_mobster as mut
+
 
 @config_enumerate
 def guide(data, K=1, tail=1, purity=0.96, clonal_beta_var=1., alpha_prior_concentration = 5, alpha_prior_rate = 10, number_of_trials_clonal_mean=100.,
@@ -21,16 +23,12 @@ def guide(data, K=1, tail=1, purity=0.96, clonal_beta_var=1., alpha_prior_concen
 
     """
     karyos = list(data.keys())
-    major = [int(str(i).split(":")[0]) for i in karyos]
-    minor = [int(str(i).split(":")[1]) for i in karyos]
 
-    lk = np.zeros(len(karyos))
+    # Here we calculate the theoretical number of clonal clusters
+    theoretical_num_clones = [mut.theo_clonal_list[kr] for kr in karyos]
 
-    theoretical_num_clones = [1 if (mn == 0 or mn == mj) else 2 for mj, mn in zip(major, minor)]
-    theoretical_clonal_means = [(purity - 0.0001) if (mn == 0 or mn == mj) else torch.tensor(
-        [(mj / (mj + mn)) * purity, (mn / (mn + mj)) * purity]) for mj, mn in zip(major, minor)]
-    theoretical_clonal_means = [0.5 * purity if (mn == mj) else j for mj, mn, j in
-                                zip(major, minor, theoretical_clonal_means)]
+    # Calculate the theoretical clonal means, wihch can be analytically defined for simple karyotypes, and then multiply them by the ploidy
+    theoretical_clonal_means = [mut.theo_clonal_means_list[kr] * purity for kr in karyos]
 
     counts_clones = dict()
     for i in theoretical_num_clones:
