@@ -31,9 +31,7 @@ def log_sum_exp(args):
 
 def get_theo_clones(data):
     karyos = list(data.keys())
-    major = [int(str(i).split(":")[0]) for i in karyos]
-    minor = [int(str(i).split(":")[1]) for i in karyos]
-    theoretical_num_clones = [1 if (mn == 0 or mn == mj) else 2 for mj, mn in zip(major, minor)]
+    theoretical_num_clones = [theo_clonal_list[kr] for kr in karyos]
     return theoretical_num_clones
 
 def get_clones_counts(theoretical_num_clones):
@@ -92,7 +90,7 @@ def format_parameters_for_export_aux(data, params,k, i, theo_clones, counts_clon
 
 
     res = {"cluster_probs" : params["cluster_probs"][k].detach().numpy(),
-           "cluster_assignments" : np.argmax(params["cluster_probs"][k].detach().numpy(), axis = 0),
+           "cluster_assignments" : rename_clusters(np.argmax(params["cluster_probs"][k].detach().numpy(), axis = 0), tail, theo_clones[i]),
            "mixture_probs" : mixture_weights,
           "beta_concentration1" : beta_concentration1.detach().numpy(),
           "beta_concentration2" : beta_concentration2.detach().numpy()
@@ -102,4 +100,24 @@ def format_parameters_for_export_aux(data, params,k, i, theo_clones, counts_clon
         res["tail_scale"] = np.min(data[k].detach().numpy())
         res["tail_shape_sd"] = params['tail_sd'].detach().numpy()
 
-    return res
\ No newline at end of file
+    return res
+
+
+def rename_clusters(x,tail, theo_c):
+    res = np.empty(len(x), dtype='object')
+    uniq_clusts = np.unique(x)
+    base_idx = 0
+    clonal_num = 1
+    subclonal_num = 1
+    if tail == 1:
+        res[x == 0] = "Tail"
+        base_idx += 1
+    for i in range(base_idx, base_idx + theo_c):
+        res[x == i] = "C" + str(clonal_num)
+        clonal_num += 1
+    for i in range(base_idx + theo_c,len(uniq_clusts)):
+        res[x == i] = "S" + str(subclonal_num)
+        subclonal_num += 1
+
+    return res
+
